#!/bin/sh

# default install path
MAPLE=""

# preamble
echo "This will upgrade your Maple installation to Maple 10.06."
echo "Please ensure your version of Maple has been activated"
echo "and press ENTER to continue or CTRL+C to exit."
echo ""
read KEYPRESS

# check for a valid maple installation
echo
while [ 1 ]; do
    if [ -x "$MAPLE/bin/maple" -a -d "$MAPLE/java" ]; then
        TMPVAR=`echo "kernelopts(version);" | "$MAPLE/bin/maple" -q`;
        MAPLEVER00=`echo "${TMPVAR}" | grep "Maple 10.00"`
        MAPLEVER01=`echo "${TMPVAR}" | grep "Maple 10.01"`
        MAPLEVER02=`echo "${TMPVAR}" | grep "Maple 10.02"`
        MAPLEVER03=`echo "${TMPVAR}" | grep "Maple 10.03"`
        MAPLEVER04=`echo "${TMPVAR}" | grep "Maple 10.04"`
        MAPLEVER05=`echo "${TMPVAR}" | grep "Maple 10.05"`
        if [ -z "$MAPLEVER00" -a -z "$MAPLEVER01" -a -z "$MAPLEVER02" -a -z "$MAPLEVER03" -a -z "$MAPLEVER04" -a -z "$MAPLEVER05" ]; then
                echo "A version of Maple was installed to $MAPLE, but it does not meet this upgrade's requirements.  Upgrade aborted."
                exit 1
        else
                break
        fi
    else
        echo "Please specify the full path to the Maple 10 directory to upgrade (e.g. /usr/local/maple10) : "
        read MAPLE
    fi
done

# figure out what we are upgrading, bin.$SYS wise
DIRS="bin.DEC_ALPHA_UNIX bin.HP_RISC_UNIX bin.IBM_INTEL_LINUX bin.IBM_RISC_UNIX bin.SGI_MIPS_UNIX bin.SUN_SPARC_SOLARIS bin.X86_64_LINUX bin.ITANIUM_LINUX"
REQDIRS="lib data examples man extern license"
JAR_FILES="externalcall.jar jopenmaple.jar mapleclient.jar mapleresource.jar mapleresource_ja.jar mapletbuilder.jar maplewks.jar mathdoc.jar mathworksheet.jar mathxmltools.jar pen.jar plot.jar wksloader.jar WMFWriter.jar jai_codec.jar jai_core.jar mapleresource_en.jar"
UPDATES=""
TOUPDATE=""

# check for required folders
for i in $REQDIRS java bin; do
    if [ ! -d "$MAPLE/$i" ]; then
        echo "ERROR: Required Maple 10 directory $MAPLE/$i could not be found.  Upgrade aborted."
        exit 1
    fi
done

# find out what binary specific directories to update
NO_DIRS=0
for i in $DIRS; do
    if [ -d "$MAPLE/$i" ]; then
        UPDATES="${UPDATES} $i"
		NO_DIRS="`expr $NO_DIRS + 1`"
		PLATFORM="`echo $i | sed -e 's/bin//'`"
    fi
done

if [ -z "$UPDATES" ]; then
    echo "ERROR: No platform specific directories found.  Upgrade aborted."
    exit 1
fi


echo
echo "The upgrade process will make updates to the following files and directories"
echo
echo "$MAPLE/Install.html"

# determine updated directories
TOUPDATE="$UPDATES $REQDIRS"
if [ -f "$MAPLE/bin/MapleActivation.jar" ]; then
        for i in $TOUPDATE java bin; do
            echo $MAPLE/$i
        done
else
        for i in $TOUPDATE java; do
            echo $MAPLE/$i
        done
fi

echo
echo "If you do not wish to continue, press CTRL+C now"
echo
echo "Press ENTER to continue"
read KEYPRESS

# upgrade directories
echo "Updating $MAPLE/Install.html"
cp -f Install.html $MAPLE/

for i in $TOUPDATE; do
    echo "Upgrading $MAPLE/$i"
    cp -Rf $i/* "$MAPLE/$i"
done

# update java directory
echo "Upgrading $MAPLE/java"
for i in $JAR_FILES; do
    cp -Rf "java/$i" "$MAPLE/java/$i"
done

# update MapleActivation.jar if present in java directory
if [ -f "$MAPLE/java/MapleActivation.jar" ]; then
    cp -Rf bin/MapleActivation.jar "$MAPLE/java"
fi

# update properties file if present
if [ "$NO_DIRS" = "1" ]; then
	 if [ -f "$MAPLE/java/product.app.pu.properties" ]; then
			cp -Rf java/product.app.pu.properties$PLATFORM "$MAPLE/java/product.app.pu.properties"
	 fi
fi

# update MapleActivation.jar if present in bin directory
if [ -f "$MAPLE/bin/MapleActivation.jar" ]; then
    echo "Upgrading $MAPLE/bin"
    cp -Rf bin/* "$MAPLE/bin"
fi

echo
echo "Done."
echo
